"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.baseDirs = void 0;
var os_1 = require("os");
var utils_1 = require("./utils");
var baseDirsWindows = {
    home: function () { return process.env.FOLDERID_Profile; },
    cache: function () { return process.env.FOLDERID_LocalAppData; },
    config: function () { return process.env.FOLDERID_RoamingAppData; },
    data: function () { return process.env.FOLDERID_RoamingAppData; },
    dataLocal: function () { return process.env.FOLDERID_LocalAppData; },
    executable: function () { return null; },
    preference: function () { return process.env.FOLDERID_RoamingAppData; },
    runtime: function () { return null; },
};
var baseDirsMac = {
    home: function () { return os_1.homedir(); },
    cache: function () { return utils_1.homerel("Library/Caches"); },
    config: function () { return utils_1.homerel("Library/Application Support"); },
    data: function () { return utils_1.homerel("Library/Application Support"); },
    dataLocal: function () { return utils_1.homerel("Library/Application Support"); },
    executable: function () { return null; },
    preference: function () { return utils_1.homerel("Library/Preferences"); },
    runtime: function () { return null; },
};
var baseDirsLinux = {
    home: function () { return os_1.homedir(); },
    cache: function () { return utils_1.envrel("XDG_CACHE_HOME") || utils_1.homerel(".cache"); },
    config: function () { return utils_1.envrel("XDG_CONFIG_HOME") || utils_1.homerel(".config"); },
    data: function () { return utils_1.envrel("XDG_DATA_HOME") || utils_1.homerel(".local/share"); },
    dataLocal: function () { return utils_1.envrel("XDG_DATA_HOME") || utils_1.homerel(".local/share"); },
    executable: function () {
        return utils_1.envrel("XDG_BIN_HOME", "../bin") ||
            utils_1.envrel("XDG_DATA_HOME", "../bin") ||
            utils_1.homerel(".local/bin");
    },
    preference: function () { return utils_1.envrel("XDG_CONFIG_HOME") || utils_1.homerel(".config"); },
    runtime: function () { return utils_1.envrel("XDG_RUNTIME_DIR"); },
};
exports.baseDirs = utils_1.isWin()
    ? baseDirsWindows
    : utils_1.isMac()
        ? baseDirsMac
        : baseDirsLinux;
