"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.projectDirs = exports.projectToString = void 0;
var utils_1 = require("./utils");
function projectToString(_a) {
    var qualifier = _a.qualifier, organization = _a.organization, application = _a.application;
    if (utils_1.isWin()) {
        return organization + "/" + application;
    }
    else if (utils_1.isMac()) {
        return (qualifier +
            "." +
            organization.replace(/ /g, "-") +
            "." +
            application.replace(/ /g, "-"));
    }
    else {
        return application.toLowerCase().replace(/ /g, "");
    }
}
exports.projectToString = projectToString;
function forceProjectToString(project) {
    return typeof project === "string" ? project : projectToString(project);
}
var projectDirsWin = {
    cache: function (project) {
        return utils_1.envrel("FOLDERID_LocalAppData", forceProjectToString(project), "cache");
    },
    config: function (project) {
        return utils_1.envrel("FOLDERID_RoamingAppData", forceProjectToString(project), "config");
    },
    data: function (project) {
        return utils_1.envrel("FOLDERID_RoamingAppData", forceProjectToString(project), "data");
    },
    dataLocal: function (project) {
        return utils_1.envrel("FOLDERID_LocalAppData", forceProjectToString(project), "data");
    },
    preference: function (project) {
        return utils_1.envrel("FOLDERID_RoamingAppData", forceProjectToString(project), "config");
    },
    runtime: function (_project) { return null; },
};
var projectDirsMac = {
    cache: function (project) {
        return utils_1.homerel("Library", "Caches", forceProjectToString(project));
    },
    config: function (project) {
        return utils_1.homerel("Library", "Application Support", forceProjectToString(project));
    },
    data: function (project) {
        return utils_1.homerel("Library", "Application Support", forceProjectToString(project));
    },
    dataLocal: function (project) {
        return utils_1.homerel("Library", "Application Support", forceProjectToString(project));
    },
    preference: function (project) {
        return utils_1.homerel("Library", "Preferences", forceProjectToString(project));
    },
    runtime: function (_project) { return null; },
};
var projectDirsLinux = {
    cache: function (project) {
        return utils_1.envrel("XDG_CACHE_HOME", forceProjectToString(project)) ||
            utils_1.homerel(".cache", forceProjectToString(project));
    },
    config: function (project) {
        return utils_1.envrel("XDG_CONFIG_HOME", forceProjectToString(project)) ||
            utils_1.homerel(".config", forceProjectToString(project));
    },
    data: function (project) {
        return utils_1.envrel("XDG_DATA_HOME", forceProjectToString(project)) ||
            utils_1.homerel(".local/share", forceProjectToString(project));
    },
    dataLocal: function (project) {
        return utils_1.envrel("XDG_DATA_HOME", forceProjectToString(project)) ||
            utils_1.homerel(".local/share", forceProjectToString(project));
    },
    preference: function (project) {
        return utils_1.envrel("XDG_CONFIG_HOME", forceProjectToString(project)) ||
            utils_1.homerel(".config", forceProjectToString(project));
    },
    runtime: function (project) {
        return utils_1.envrel("XDG_RUNTIME_DIR", forceProjectToString(project));
    },
};
exports.projectDirs = utils_1.isWin()
    ? projectDirsWin
    : utils_1.isMac()
        ? projectDirsMac
        : projectDirsLinux;
