"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userDirs = exports.readUserDirs = void 0;
var os_1 = require("os");
var fs_1 = require("fs");
var path_1 = require("path");
var utils_1 = require("./utils");
var baseDirs_1 = require("./baseDirs");
function readUserDirs() {
    if (utils_1.isWin() || utils_1.isMac()) {
        return;
    }
    try {
        var content = fs_1.readFileSync(path_1.resolve(baseDirs_1.baseDirs.config(), "user-dirs.dirs")).toString();
        var vars = utils_1.parseUserDirs(content);
        vars.forEach(function (_a) {
            var envVar = _a[0], value = _a[1];
            utils_1.extraEnv["XDG_" + envVar + "_DIR"] = utils_1.homerel(value);
        });
    }
    catch (err) {
        // should we log error or fail silently?
        console.error(err);
    }
}
exports.readUserDirs = readUserDirs;
var userDirsWin = {
    home: function () { return utils_1.envrel("FOLDERID_Profile"); },
    audio: function () { return utils_1.envrel("FOLDERID_Music"); },
    desktop: function () { return utils_1.envrel("FOLDERID_Desktop"); },
    document: function () { return utils_1.envrel("FOLDERID_Documents"); },
    download: function () { return utils_1.envrel("FOLDERID_Downloads"); },
    font: function () { return null; },
    picture: function () { return utils_1.envrel("FOLDERID_Pictures"); },
    public: function () { return utils_1.envrel("FOLDERID_Public"); },
    template: function () { return utils_1.envrel("FOLDERID_Templates"); },
    video: function () { return utils_1.envrel("FOLDERID_Videos"); },
};
var userDirsMac = {
    home: function () { return os_1.homedir(); },
    audio: function () { return utils_1.homerel("Music"); },
    desktop: function () { return utils_1.homerel("Desktop"); },
    document: function () { return utils_1.homerel("Documents"); },
    download: function () { return utils_1.homerel("Downloads"); },
    font: function () { return utils_1.homerel("Library/Fonts"); },
    picture: function () { return utils_1.homerel("Pictures"); },
    public: function () { return utils_1.homerel("Public"); },
    template: function () { return null; },
    video: function () { return utils_1.homerel("Movies"); },
};
var userDirsLinux = {
    home: function () { return os_1.homedir(); },
    audio: function () { return utils_1.envrel("XDG_MUSIC_DIR"); },
    desktop: function () { return utils_1.envrel("XDG_DESKTOP_DIR"); },
    document: function () { return utils_1.envrel("XDG_DOCUMENTS_DIR"); },
    download: function () { return utils_1.envrel("XDG_DOWNLOAD_DIR"); },
    font: function () { return utils_1.envrel("XDG_DATA_HOME", "fonts") || utils_1.homerel(".local/share/fonts"); },
    picture: function () { return utils_1.envrel("XDG_PICTURES_DIR"); },
    public: function () { return utils_1.envrel("XDG_PUBLICSHARE_DIR"); },
    template: function () { return utils_1.envrel("XDG_TEMPLATES_DIR"); },
    video: function () { return utils_1.envrel("XDG_VIDEOS_DIR"); },
};
readUserDirs();
exports.userDirs = utils_1.isWin()
    ? userDirsWin
    : utils_1.isMac()
        ? userDirsMac
        : userDirsLinux;
