import { homedir } from "os";
import { envrel, homerel, isMac, isWin } from "./utils";
var baseDirsWindows = {
    home: function () { return process.env.FOLDERID_Profile; },
    cache: function () { return process.env.FOLDERID_LocalAppData; },
    config: function () { return process.env.FOLDERID_RoamingAppData; },
    data: function () { return process.env.FOLDERID_RoamingAppData; },
    dataLocal: function () { return process.env.FOLDERID_LocalAppData; },
    executable: function () { return null; },
    preference: function () { return process.env.FOLDERID_RoamingAppData; },
    runtime: function () { return null; },
};
var baseDirsMac = {
    home: function () { return homedir(); },
    cache: function () { return homerel("Library/Caches"); },
    config: function () { return homerel("Library/Application Support"); },
    data: function () { return homerel("Library/Application Support"); },
    dataLocal: function () { return homerel("Library/Application Support"); },
    executable: function () { return null; },
    preference: function () { return homerel("Library/Preferences"); },
    runtime: function () { return null; },
};
var baseDirsLinux = {
    home: function () { return homedir(); },
    cache: function () { return envrel("XDG_CACHE_HOME") || homerel(".cache"); },
    config: function () { return envrel("XDG_CONFIG_HOME") || homerel(".config"); },
    data: function () { return envrel("XDG_DATA_HOME") || homerel(".local/share"); },
    dataLocal: function () { return envrel("XDG_DATA_HOME") || homerel(".local/share"); },
    executable: function () {
        return envrel("XDG_BIN_HOME", "../bin") ||
            envrel("XDG_DATA_HOME", "../bin") ||
            homerel(".local/bin");
    },
    preference: function () { return envrel("XDG_CONFIG_HOME") || homerel(".config"); },
    runtime: function () { return envrel("XDG_RUNTIME_DIR"); },
};
export var baseDirs = isWin()
    ? baseDirsWindows
    : isMac()
        ? baseDirsMac
        : baseDirsLinux;
