import { envrel, homerel, isMac, isWin } from "./utils";
export function projectToString(_a) {
    var qualifier = _a.qualifier, organization = _a.organization, application = _a.application;
    if (isWin()) {
        return organization + "/" + application;
    }
    else if (isMac()) {
        return (qualifier +
            "." +
            organization.replace(/ /g, "-") +
            "." +
            application.replace(/ /g, "-"));
    }
    else {
        return application.toLowerCase().replace(/ /g, "");
    }
}
function forceProjectToString(project) {
    return typeof project === "string" ? project : projectToString(project);
}
var projectDirsWin = {
    cache: function (project) {
        return envrel("FOLDERID_LocalAppData", forceProjectToString(project), "cache");
    },
    config: function (project) {
        return envrel("FOLDERID_RoamingAppData", forceProjectToString(project), "config");
    },
    data: function (project) {
        return envrel("FOLDERID_RoamingAppData", forceProjectToString(project), "data");
    },
    dataLocal: function (project) {
        return envrel("FOLDERID_LocalAppData", forceProjectToString(project), "data");
    },
    preference: function (project) {
        return envrel("FOLDERID_RoamingAppData", forceProjectToString(project), "config");
    },
    runtime: function (_project) { return null; },
};
var projectDirsMac = {
    cache: function (project) {
        return homerel("Library", "Caches", forceProjectToString(project));
    },
    config: function (project) {
        return homerel("Library", "Application Support", forceProjectToString(project));
    },
    data: function (project) {
        return homerel("Library", "Application Support", forceProjectToString(project));
    },
    dataLocal: function (project) {
        return homerel("Library", "Application Support", forceProjectToString(project));
    },
    preference: function (project) {
        return homerel("Library", "Preferences", forceProjectToString(project));
    },
    runtime: function (_project) { return null; },
};
var projectDirsLinux = {
    cache: function (project) {
        return envrel("XDG_CACHE_HOME", forceProjectToString(project)) ||
            homerel(".cache", forceProjectToString(project));
    },
    config: function (project) {
        return envrel("XDG_CONFIG_HOME", forceProjectToString(project)) ||
            homerel(".config", forceProjectToString(project));
    },
    data: function (project) {
        return envrel("XDG_DATA_HOME", forceProjectToString(project)) ||
            homerel(".local/share", forceProjectToString(project));
    },
    dataLocal: function (project) {
        return envrel("XDG_DATA_HOME", forceProjectToString(project)) ||
            homerel(".local/share", forceProjectToString(project));
    },
    preference: function (project) {
        return envrel("XDG_CONFIG_HOME", forceProjectToString(project)) ||
            homerel(".config", forceProjectToString(project));
    },
    runtime: function (project) {
        return envrel("XDG_RUNTIME_DIR", forceProjectToString(project));
    },
};
export var projectDirs = isWin()
    ? projectDirsWin
    : isMac()
        ? projectDirsMac
        : projectDirsLinux;
