import { homedir } from "os";
import { readFileSync } from "fs";
import { resolve } from "path";
import { envrel, homerel, isWin, isMac, parseUserDirs, extraEnv, } from "./utils";
import { baseDirs } from "./baseDirs";
export function readUserDirs() {
    if (isWin() || isMac()) {
        return;
    }
    try {
        var content = readFileSync(resolve(baseDirs.config(), "user-dirs.dirs")).toString();
        var vars = parseUserDirs(content);
        vars.forEach(function (_a) {
            var envVar = _a[0], value = _a[1];
            extraEnv["XDG_" + envVar + "_DIR"] = homerel(value);
        });
    }
    catch (err) {
        // should we log error or fail silently?
        console.error(err);
    }
}
var userDirsWin = {
    home: function () { return envrel("FOLDERID_Profile"); },
    audio: function () { return envrel("FOLDERID_Music"); },
    desktop: function () { return envrel("FOLDERID_Desktop"); },
    document: function () { return envrel("FOLDERID_Documents"); },
    download: function () { return envrel("FOLDERID_Downloads"); },
    font: function () { return null; },
    picture: function () { return envrel("FOLDERID_Pictures"); },
    public: function () { return envrel("FOLDERID_Public"); },
    template: function () { return envrel("FOLDERID_Templates"); },
    video: function () { return envrel("FOLDERID_Videos"); },
};
var userDirsMac = {
    home: function () { return homedir(); },
    audio: function () { return homerel("Music"); },
    desktop: function () { return homerel("Desktop"); },
    document: function () { return homerel("Documents"); },
    download: function () { return homerel("Downloads"); },
    font: function () { return homerel("Library/Fonts"); },
    picture: function () { return homerel("Pictures"); },
    public: function () { return homerel("Public"); },
    template: function () { return null; },
    video: function () { return homerel("Movies"); },
};
var userDirsLinux = {
    home: function () { return homedir(); },
    audio: function () { return envrel("XDG_MUSIC_DIR"); },
    desktop: function () { return envrel("XDG_DESKTOP_DIR"); },
    document: function () { return envrel("XDG_DOCUMENTS_DIR"); },
    download: function () { return envrel("XDG_DOWNLOAD_DIR"); },
    font: function () { return envrel("XDG_DATA_HOME", "fonts") || homerel(".local/share/fonts"); },
    picture: function () { return envrel("XDG_PICTURES_DIR"); },
    public: function () { return envrel("XDG_PUBLICSHARE_DIR"); },
    template: function () { return envrel("XDG_TEMPLATES_DIR"); },
    video: function () { return envrel("XDG_VIDEOS_DIR"); },
};
readUserDirs();
export var userDirs = isWin()
    ? userDirsWin
    : isMac()
        ? userDirsMac
        : userDirsLinux;
